<?php

App::uses('CakeEventListener', 'Event');

class WaiverListener implements CakeEventListener {

	public function implementedEvents() {
		return array(
			'Model.Participant.afterCreate' => 'sendEmails'
		);
	}

	public function sendEmails(CakeEvent $Event) {
		if (! empty($Event->data['salesRef'])) {

			// Load all participants we've not yet emailed with this ref
			$Participant = ClassRegistry::init('BuzzWaivers.Participant');

			$participants = $Participant->find('all', array(
				'conditions' => array(
					'sales_ref' => $Event->data['salesRef'],
					'emailed' => 0
				)
			));

			if (! empty($participants)) {

				$Booking = ClassRegistry::init('BuzzBookings.Booking');
				$systemBooking = $Booking->find('first', array(
					'conditions' => array(
						'sales_ref' => $Event->data['salesRef']
					)
				));

				// Load the booking details
				$Api = ClassRegistry::init('BuzzWaivers.WaiversApi');
				$booking = $Api->getBooking($Event->data['salesRef'], $participants[0]['Participant']['booking_date']);
				$details = '';
				if (! empty($systemBooking)) {

					$purchase = ClassRegistry::init('BuzzBookings.Booking')->getPurchase($systemBooking['Booking']['id']);

					$Controller = new Controller();
					$Controller->helpers = ['BuzzTranslate.I18n'];
					$View = new View($Controller);
					$View = new View($Controller);
					$View->set('data', $purchase);
					$details = $View->render('BuzzBookings./Bookings/email_basket', 'ajax');
				}

				$Email = ClassRegistry::init('BuzzEmails.Email');
				foreach ($participants as $key => $participant) {

					$waiverUrl = Router::url(array(
						'plugin' => 'buzz_waivers',
						'controller' => 'waivers',
						'action' => 'participants',
						$participant['Participant']['id']
					), true);

					$waiverLink = '<a href="' . $waiverUrl . '">' . $waiverUrl . '</a>';

					$emailData = $Email->generateEmailData(
						'BuzzWaivers.waiver_notice',
						array(
							'firstName' => $participant['Participant']['first_name'],
							'lastName' => $participant['Participant']['last_name'],
							'bookedItem' => $booking[0]['description'],
							'date' => date('j F Y', strtotime($purchase['Booking']['booking_date'])),
							'time' => date('H:i', strtotime($purchase['Booking']['booking_date'])),
							'salesRef' => $purchase['Booking']['sales_ref'],
							'checkin' => $purchase['Booking']['check_in_time'],
							'waiverLink' => $waiverLink,
							'details' => $details
						)
					);

					$Email->queueEmail(
						$emailData['Email']['subject'],
						$emailData['Email']['content'],
						array($participant['Participant']['email'] => $participant['Participant']['first_name'] . ' ' . $participant['Participant']['last_name']),
						$emailData['Email']['from']
					);

					$participants[$key]['Participant']['emailed'] = 1;
				}

				$Participant->saveMany($participants, array('deep' => true));
			}
		}
	}

}
